@@ -13,8 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from six.moves.urllib import parse
+
 from heatclient.openstack.common.apiclient import base
-from heatclient.openstack.common.py3kcompat import urlutils
 from heatclient.openstack.common import strutils
 from heatclient.v1 import stacks
 
@@ -38,11 +39,13 @@ class Resource(base.Resource):
 class ResourceManager(stacks.StackChildManager):
     resource_class = Resource
 
-    def list(self, stack_id):
+    def list(self, stack_id, nested_depth=0):
         """Get a list of resources.
         :rtype: list of :class:`Resource`
         """
         url = '/stacks/%s/resources' % stack_id
+        if nested_depth:
+            url += '?nested_depth=%s' % nested_depth
         return self._list(url, "resources")
 
     def get(self, stack_id, resource_name):
@@ -52,10 +55,9 @@ class ResourceManager(stacks.StackChildManager):
         :param resource_name: ID of resource to get the details for
         """
         stack_id = self._resolve_stack_id(stack_id)
-        # Use urlutils for python2/python3 compatibility
         url_str = '/stacks/%s/resources/%s' % (
-                  urlutils.quote(stack_id, ''),
-                  urlutils.quote(strutils.safe_encode(resource_name), ''))
+                  parse.quote(stack_id, ''),
+                  parse.quote(strutils.safe_encode(resource_name), ''))
         resp, body = self.client.json_request('GET', url_str)
         return Resource(self, body['resource'])
 
@@ -66,10 +68,9 @@ class ResourceManager(stacks.StackChildManager):
         :param resource_name: ID of resource to get metadata for
         """
         stack_id = self._resolve_stack_id(stack_id)
-        # Use urlutils for python2/python3 compatibility
         url_str = '/stacks/%s/resources/%s/metadata' % (
-                  urlutils.quote(stack_id, ''),
-                  urlutils.quote(strutils.safe_encode(resource_name), ''))
+                  parse.quote(stack_id, ''),
+                  parse.quote(strutils.safe_encode(resource_name), ''))
         resp, body = self.client.json_request('GET', url_str)
         return body['metadata']
 
@@ -81,14 +82,16 @@ class ResourceManager(stacks.StackChildManager):
         """
         stack_id = self._resolve_stack_id(stack_id)
         url_str = '/stacks/%s/resources/%s/signal' % (
-                  urlutils.quote(stack_id, ''),
-                  urlutils.quote(strutils.safe_encode(resource_name), ''))
+                  parse.quote(stack_id, ''),
+                  parse.quote(strutils.safe_encode(resource_name), ''))
         resp, body = self.client.json_request('POST', url_str, data=data)
         return body
 
     def generate_template(self, resource_name):
-        # Use urlutils for python2/python3 compatibility
+        """DEPRECATED! Use `generate_template` of `ResourceTypeManager`
+        instead.
+        """
         url_str = '/resource_types/%s/template' % (
-                  urlutils.quote(strutils.safe_encode(resource_name), ''))
+                  parse.quote(strutils.safe_encode(resource_name), ''))
         resp, body = self.client.json_request('GET', url_str)
         return body
